@@ -25,10 +25,11 @@ def request(token='', ticker='', family='', group='', market='', country='',
             fixing=Enumerations.Fixing.EOD, fieldType='', versionType=Enumerations.VersionType.Version_Unspecified,
             author='', version='', quality=Enumerations.Quality.Quality_Unspecified, timeOut=300, timeFrecuency=0.5,
             fileName='', format='dataFrame', **kwargs):
+    countryString = country
     country = Enumerations.Country.fromString(country)
     if app != '':
         return requestApplication(token, app, help, timeOut, timeFrecuency, fileName, format, **kwargs, ticker=ticker,
-                                  family=family, group=group, market=market, country=country, document=document,
+                                  family=family, group=group, market=market, country=countryString, document=document,
                                   item=item, chapter=chapter, section=section, subsection=subsection,
                                   paragraph=paragraph, dateStart=dateStart, dateEnd=dateEnd, fixing=fixing,
                                   fieldType=fieldType, versionType=versionType, author=author, version=version,
